Index: trunk/Ohana/src/libdvo/include/dvo.h
===================================================================
--- trunk/Ohana/src/libdvo/include/dvo.h	(revision 38649)
+++ trunk/Ohana/src/libdvo/include/dvo.h	(revision 38986)
@@ -171,7 +171,9 @@
   ID_PROPER            = 0x00000010, // star with large proper motion
   ID_TRANSIENT         = 0x00000020, // identified as a non-periodic (stationary) transient
-  ID_VARIABLE          = 0x00000040, // identified as a period variable
+  ID_VARIABLE          = 0x00000040, // identified as a periodic variable
   ID_ASTEROID          = 0x00000080, // identified with a known solar-system object (asteroid or other)
-  // bits 0x00000100 - 0x00008000 are currently unused
+  ID_STACK_ASTROM      = 0x00000100, // stack position used for astrometry
+  
+  // bits 0x00000200 - 0x00008000 are currently unused
   ID_STAR_FIT_AVE      = 0x00010000, // average position fitted
   ID_STAR_FIT_PM       = 0x00020000, // proper motion fitted
@@ -813,5 +815,4 @@
   int sorted;				/* is measure table average-sorted? (NOTE this is an int only because gfits_scan %t requires it) */
 
-
   /* pointers for data manipulation */
   off_t *found_t;
@@ -819,8 +820,4 @@
 
   char *measureRank;
-//  off_t *image_t;
-//  off_t *mosaic_t;
-//  float *X_t;
-//  float *Y_t;
   int   *nOwn_t; // relastro uses this to count owned detections per object
 
@@ -840,4 +837,6 @@
 int   gfits_db_free                PROTO((FITS_DB *db));
 
+int gfits_fread_uncompressed (Catalog *catalog, FTable *ftable, char *nativeOrder, char VERBOSE);
+
 char *libdvo_version (void);
 
@@ -903,4 +902,6 @@
 float PhotZeroPoint (Measure *measure, Average *average, SecFilt *secfilt);
 
+int PhotSecfiltFlags (PhotCode *code, Average *average, SecFilt *secfilt);
+int PhotNcode (PhotCode *code, Average *average, SecFilt *secfilt);
 int   PhotNphot (PhotCode *code, Average *average, SecFilt *secfilt, dvoMagClassType class, dvoMagSourceType source);
 float PhotMstdev (PhotCode *code, Average *average, SecFilt *secfilt, dvoMagClassType class, dvoMagSourceType source);
@@ -969,6 +970,6 @@
 void dvo_catalog_test (Catalog *catalog, int halt);
 
-int dvo_catalog_backup (Catalog *catalog, int primary);
-int dvo_catalog_unlink_backup (Catalog *catalog, int primary);
+int dvo_catalog_backup (Catalog *catalog, char *suffix, int primary);
+int dvo_catalog_unlink_backup (Catalog *catalog, char *suffix, int primary);
 
 /* catmode-specific APIs */
